@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_logs
-import aws_cdk.cdk
+import aws_cdk.core
 import aws_cdk.cx_api
 __all__ = []
 
